add_add_pgp_key

Function add_add_pgp_key 

pub fn add_add_pgp_key(lua: &Lua, quiet: bool) -> Result<(), Error>
Adds the addPgpKey function to the Lua global environment.

This function allows package scripts to import trusted PGP keys.

Errors

Returns an error if the addPgpKey function cannot be added to the Lua environment.