download_with_progress

Function download_with_progress 

pub fn download_with_progress(
    url: &str,
    dest_path: &Path,
    quiet: bool,
) -> Result<(), Error>
Downloads a file from the given URL to the destination path with a progress bar.

Errors

Returns an mlua::Error if the download fails after several attempts or if there is an error creating the destination file.