Module fs

Module fs 

Filesystem and staging utilities.

Functions

add_file_util
Exposes filesystem and staging utilities to the Lua environment.
add_find_util
Adds file finding utilities to the UTILS.FIND table.
add_fs_util
Adds general filesystem utilities to the UTILS.FS table.
add_zchmod
Adds the zchmod function to the Lua environment for changing file permissions.
add_zchown
Adds the zchown function to the Lua environment for changing file ownership.
add_zcp
Adds the zcp function to the Lua environment for staging files.
add_zdoc
Adds the zdoc function to the Lua environment for staging documentation files.
add_zlicense
Adds the zlicense function to the Lua environment for staging licenses.
add_zln
Adds the zln function to the Lua environment for creating symbolic links.
add_zman
Adds the zman function to the Lua environment for staging manual pages.
add_zmkdir
Adds the zmkdir function to the Lua environment for creating directories.
add_zrm
Adds the zrm function to the Lua environment for removing files during uninstallation.
add_zsed
Adds the zsed function to the Lua environment for text replacements in files.
add_zshell
Adds the zshell function to the Lua environment for staging shell completions.