add_zchmod

Function add_zchmod 

pub fn add_zchmod(lua: &Lua) -> Result<(), Error>
Adds the zchmod function to the Lua environment for changing file permissions.

Errors

Returns an error if the zchmod function cannot be set in the global environment.