add_zcp

Function add_zcp 

pub fn add_zcp(lua: &Lua) -> Result<(), Error>
Adds the zcp function to the Lua environment for staging files.

Errors

Returns an error if the zcp function cannot be set in the global environment.