add_zdoc

Function add_zdoc 

pub fn add_zdoc(lua: &Lua) -> Result<(), Error>
Adds the zdoc function to the Lua environment for staging documentation files.

Errors

Returns an error if the zdoc function cannot be set in the global environment.