add_zlicense

Function add_zlicense 

pub fn add_zlicense(lua: &Lua) -> Result<(), Error>
Adds the zlicense function to the Lua environment for staging licenses.

Errors

Returns an error if the zlicense function cannot be set in the global environment.