add_zln

Function add_zln 

pub fn add_zln(lua: &Lua) -> Result<(), Error>
Adds the zln function to the Lua environment for creating symbolic links.

Errors

Returns an error if the zln function cannot be set in the global environment.