pub fn add_zsed(lua: &Lua, quiet: bool) -> Result<(), Error>
Adds the zsed function to the Lua environment for text replacements in files.
zsed
Returns an error if the zsed function cannot be set in the global environment.