add_zshell

Function add_zshell 

pub fn add_zshell(lua: &Lua) -> Result<(), Error>
Adds the zshell function to the Lua environment for staging shell completions.

Errors

Returns an error if the zshell function cannot be set in the global environment.