add_include_util

Function add_include_util 

pub fn add_include_util(lua: &Lua, current_path: &Path) -> Result<(), Error>
Adds the INCLUDE function to the Lua environment for executing other Lua files.

Errors

Returns an error if the INCLUDE function cannot be set in the global environment.