System command execution and patching.
Functions
- add_
cmd_ util - Exposes system command and patching utilities to the Lua environment.
- add_
zpatch - Adds the
zpatchfunction to the Lua environment for applying patches.
System command execution and patching.
zpatch function to the Lua environment for applying patches.