add_cmd_util

Function add_cmd_util 

pub fn add_cmd_util(lua: &Lua, quiet: bool) -> Result<(), Error>
Exposes system command and patching utilities to the Lua environment.

Errors

Returns an error if the cmd function cannot be registered in the Lua globals.

Panics

Panics if the internal shell session mutex is poisoned.