pub fn add_zpatch(lua: &Lua, quiet: bool) -> Result<(), Error>
Adds the zpatch function to the Lua environment for applying patches.
zpatch
Returns an error if the zpatch function cannot be registered in the Lua globals.