High-level Lua environment setup and execution functions. High-level Lua environment setup and execution functions.
This module provides the setup_lua_environment function, which is
responsible for initializing the Lua state with all the necessary globals,
tables, and utility functions required by Zoi package scripts.
Functions
- setup_
lua_ environment - Bootstraps the Lua environment for executing a package definition.