File download utilities with progress reporting. File download utilities with progress reporting for the Lua environment.
This module provides functions to download files from URLs, including support for progress bars and hash verification of downloaded files.
Functions
- add_
download_ util - Registers the
UTILS.DOWNLOADfunction in the Lua environment. - download_
with_ progress - Downloads a file from the given URL to the destination path with a progress bar.