Filesystem and staging utilities.
Functions
- add_
file_ util - Exposes filesystem and staging utilities to the Lua environment.
- add_
find_ util - Adds file finding utilities to the
UTILS.FINDtable. - add_
fs_ util - Adds general filesystem utilities to the
UTILS.FStable. - add_
zchmod - Adds the
zchmodfunction to the Lua environment for changing file permissions. - add_
zchown - Adds the
zchownfunction to the Lua environment for changing file ownership. - add_zcp
- Adds the
zcpfunction to the Lua environment for staging files. - add_
zdoc - Adds the
zdocfunction to the Lua environment for staging documentation files. - add_
zlicense - Adds the
zlicensefunction to the Lua environment for staging licenses. - add_zln
- Adds the
zlnfunction to the Lua environment for creating symbolic links. - add_
zman - Adds the
zmanfunction to the Lua environment for staging manual pages. - add_
zmkdir - Adds the
zmkdirfunction to the Lua environment for creating directories. - add_zrm
- Adds the
zrmfunction to the Lua environment for removing files during uninstallation. - add_
zsed - Adds the
zsedfunction to the Lua environment for text replacements in files. - add_
zshell - Adds the
zshellfunction to the Lua environment for staging shell completions.