pub fn add_zchmod(lua: &Lua) -> Result<(), Error>
Adds the zchmod function to the Lua environment for changing file permissions.
zchmod
Returns an error if the zchmod function cannot be set in the global environment.