pub fn add_zchown(lua: &Lua) -> Result<(), Error>
Adds the zchown function to the Lua environment for changing file ownership.
zchown
Returns an error if the zchown function cannot be set in the global environment.