pub fn add_zdoc(lua: &Lua) -> Result<(), Error>
Adds the zdoc function to the Lua environment for staging documentation files.
zdoc
Returns an error if the zdoc function cannot be set in the global environment.