pub fn add_zlicense(lua: &Lua) -> Result<(), Error>
Adds the zlicense function to the Lua environment for staging licenses.
zlicense
Returns an error if the zlicense function cannot be set in the global environment.