pub fn add_zln(lua: &Lua) -> Result<(), Error>
Adds the zln function to the Lua environment for creating symbolic links.
zln
Returns an error if the zln function cannot be set in the global environment.