pub fn add_zman(lua: &Lua) -> Result<(), Error>
Adds the zman function to the Lua environment for staging manual pages.
zman
Returns an error if the zman function cannot be set in the global environment.