pub fn add_zmkdir(lua: &Lua) -> Result<(), Error>
Adds the zmkdir function to the Lua environment for creating directories.
zmkdir
Returns an error if the zmkdir function cannot be set in the global environment.