pub fn add_zrm(lua: &Lua) -> Result<(), Error>
Adds the zrm function to the Lua environment for removing files during uninstallation.
zrm
Returns an error if the zrm function cannot be set in the global environment.