pub fn add_zshell(lua: &Lua) -> Result<(), Error>
Adds the zshell function to the Lua environment for staging shell completions.
zshell
Returns an error if the zshell function cannot be set in the global environment.