Module system

Module system 

System command execution and patching.

Functions

add_cmd_util
Exposes system command and patching utilities to the Lua environment.
add_zpatch
Adds the zpatch function to the Lua environment for applying patches.